# Keats

![John Keats](assets/keats.jpg)

Keats is an utilities package for poetry.

Features include forced change logs, release scripts, and package version control.

## Usage

```
keats bump <VERSION>
```

```
# get the package version number
keats version
```

## Installation


```
# globally install keats
pip install keats
```

```
# locally install keats
poetry add --dev keats

# run keats
poetry run keats
```